@@ -511,8 +511,13 @@ err1:
 }
 
 /* replace memory allocation methods for memory check */
+/* For compatibility with g++ >= 4.7 compilers _GLIBCXX_THROW
+ *  should be used as a guard, otherwise use traditional definition */
+#ifndef _GLIBCXX_THROW
+#define _GLIBCXX_THROW throw
+#endif
 
-void * operator new(size_t size) throw (std::bad_alloc)
+void * operator new(size_t size) _GLIBCXX_THROW (std::bad_alloc)
 {
   return gmalloc(size);
 }
@@ -522,7 +527,7 @@ void operator delete(void *p) throw ()
   gfree(p);
 }
 
-void * operator new[](size_t size) throw (std::bad_alloc)
+void * operator new[](size_t size) _GLIBCXX_THROW (std::bad_alloc)
 {
   return gmalloc(size);
 }
